@@ -3,12 +3,10 @@ from .dataclasses import Status
 
 
 class Core:
+    api = "https://expressmoney.ew.r.appspot.com/core/{}/"
 
-    api = None
-
-    def __init__(self, api):
-        self.api = api
-
+    def __init__(self, endpoint):
+        self.api = self.api.format(endpoint)
 
     def list(self):
         """
@@ -16,21 +14,19 @@ class Core:
         """
         return self._response()
 
-
     def retrieve(self, lookup_field):
         """
         Возвращает один объект из Core
         """
-        return self._response(lookup_field=lookup_field, method='put')
-
+        return self._response(lookup_field=lookup_field)
 
     def update(self, lookup_field, status, comment):
         """
         Обновляет значения полей Status и Comment сущности Event Core
         """
 
-        if status not in [Status.ERROR, Status.SUCCESS, Status.FAILURE]:
-            raise RuntimeError('Статус должен быть равен SCS, FAIL, ERROR')
+        if status not in [Status.NEW, Status.IN_PROCESS, Status.SUCCESS, Status.FAILURE, Status.ERROR, Status.CANCEL]:
+            raise RuntimeError('Статус должен быть равен NEW, INPR, SCS, FAIL, ERROR', 'CANCEL')
 
         data = {
             'status': status,
@@ -39,7 +35,6 @@ class Core:
 
         return self._response(data=data, lookup_field=lookup_field, method='put')
 
-
     def _get_url(self, lookup_field=None):
         if lookup_field:
             return self.api + str(lookup_field) + '/'
@@ -61,5 +56,7 @@ class Core:
             return response.json()
         elif response.status_code == 500:
             raise RuntimeError('ERROR CORE: {} {}'.format(response.status_code, 'Internal Server Error'))
+        elif response.status_code == 404:
+            raise RuntimeError('ERROR CORE: {} {}'.format(response.status_code, 'Object Not Found'))
         else:
             raise RuntimeError('ERROR CORE: {} {}'.format(response.status_code, response.text[:255]))
