@@ -18,11 +18,11 @@ class PubSub:
         self.topic_name = topic_name
 
     @staticmethod
-    def extract_message(event):
+    def extract_message(message):
         """
         Извлекает данные из message
         """
-        message_bytes = base64.b64decode(event['data'])
+        message_bytes = base64.b64decode(message['data'])
         message = json.loads(message_bytes)
         return message['data']['message']
 
@@ -87,50 +87,59 @@ class Functions:
         """Для Event в статусе NEW вызывает _new для IN_PROCESS вызывает _in_process"""
 
         # Получаю pk(primary key) для объекта Event
-        pk = self.pubsub.extract_message(message)
+        self._set_pk(self.pubsub.extract_message(message))
 
         # Получаю данные объекта Event по его pk
-        event = self.core.retrieve(pk)
+        self._set_event(self.core.retrieve(self.pk))
 
         # Обработка в зависимости от текущего статуса события
-        if event.get('status') == Status.NEW:
+        if self.initial_event.get('status') == Status.NEW:
 
             # Обнвляю статус на IN_PROCESS
-            self.core.update(lookup_field=pk, status=Status.IN_PROCESS, comment='Sets status from NEW to IN_PROCESS')
+            self.core.update(lookup_field=self.pk, status=Status.IN_PROCESS,
+                             comment='Sets status from NEW to IN_PROCESS')
 
             # Обрабатываю событие
-            result = self._new(event)
+            result = self._new()
 
             # Сохраняю результат
-            self.core.update(lookup_field=pk, status=result.status, comment=result.comment)
+            self.core.update(lookup_field=self.pk, status=result.status, comment=result.comment)
 
-        elif event.get('status') == Status.IN_PROCESS:
+        elif self.initial_event.get('status') == Status.IN_PROCESS:
 
             # Обрабатываю событие
-            result = self._in_process(event)
+            result = self._in_process()
 
             # Сохраняю результат
-            self.core.update(lookup_field=pk, status=result.status, comment=result.comment)
+            self.core.update(lookup_field=self.pk, status=result.status, comment=result.comment)
 
         return Status.SUCCESS, 200
 
-    def _new(self, event):
+    def _set_pk(self, pk):
+        """pk(primary key) для объекта Event"""
+        self.pk = pk
+
+    def _set_event(self, event):
+        """Данные объекта Event"""
+        self.initial_event = event
+
+    def _new(self):
         """Подготовка доменных данных и передача их в сервиса _service_new()"""
 
         user = Core('user')
         profile = Core('profile')
 
-        user_obj = user.retrieve(event.get('user'))
-        profile_obj = profile.retrieve(event.get('user'))
+        user_obj = user.retrieve(self.initial_event.get('user'))
+        profile_obj = profile.retrieve(self.initial_event.get('user'))
 
         return self._service_new({**user_obj, **profile_obj})
 
-    def _in_process(self, event):
+    def _in_process(self):
         """Подготовка доменных данных и передача их в сервиса _service_in_process()"""
 
-        return self._service_in_process(event)
+        return self._service_in_process()
 
-    def _service_in_process(self, data):
+    def _service_in_process(self):
         """Запускается для событий со статусом IN_PROCESS"""
 
         raise RuntimeError('Status IN_PROCESS недопустим для Event: {}'.format(str(data)))
